@@ -138,8 +138,13 @@ class ElectrumWindow(QMainWindow):
 
         self._close_electrum = False
         self.lite = None
-            
-        self.icon = QIcon(':icons/electrum_light_icon.png')
+
+        if sys.platform == 'darwin':
+          self.icon = QIcon(":icons/electrum_dark_icon.png")
+          #self.icon = QIcon(":icons/lock.png")
+        else:
+          self.icon = QIcon(':icons/electrum_light_icon.png')
+
         self.tray = QSystemTrayIcon(self.icon, self)
         self.tray.setToolTip('Electrum')
         self.tray.activated.connect(self.tray_activated)
@@ -284,16 +289,9 @@ class ElectrumWindow(QMainWindow):
         run_hook('load_wallet', wallet)
 
 
-    def select_wallet_file(self):
-        wallet_folder = self.wallet.storage.path
-        re.sub("(\/\w*.dat)$", "", wallet_folder)
-        file_name = unicode( QFileDialog.getOpenFileName(self, "Select your wallet file", wallet_folder) )
-        return file_name
-
-
     def open_wallet(self):
-
-        filename = self.select_wallet_file()
+        wallet_folder = self.wallet.storage.path
+        filename = unicode( QFileDialog.getOpenFileName(self, "Select your wallet file", wallet_folder) )
         if not filename:
             return
 
@@ -316,12 +314,11 @@ class ElectrumWindow(QMainWindow):
         import shutil
         path = self.wallet.storage.path
         wallet_folder = os.path.dirname(path)
-        new_filename, ok = QInputDialog.getText(self, _('Filename'), _('Current directory') + ': ' + wallet_folder + '\n' + _('Enter a filename for the copy of your wallet') + ':')
-        new_filename = unicode(new_filename)
-        if not ok or not new_filename:
+        filename = unicode( QFileDialog.getSaveFileName(self, _('Enter a filename for the copy of your wallet'), wallet_folder) )
+        if not filename:
             return
 
-        new_path = os.path.join(wallet_folder, new_filename)
+        new_path = os.path.join(wallet_folder, filename)
         if new_path != path:
             try:
                 shutil.copy2(path, new_path)
@@ -334,14 +331,15 @@ class ElectrumWindow(QMainWindow):
         import installwizard
 
         wallet_folder = os.path.dirname(self.wallet.storage.path)
-        filename, ok = QInputDialog.getText(self, _('Filename'), _('Current directory') + ': ' + wallet_folder + '\n'+_('Enter a new file name') + ':')
-        filename = unicode(filename)
-        if not ok or not filename:
+        filename = unicode( QFileDialog.getSaveFileName(self, _('Enter a new file name'), wallet_folder) )
+        if not filename:
             return
         filename = os.path.join(wallet_folder, filename)
 
         storage = WalletStorage({'wallet_path': filename})
-        assert not storage.file_exists
+        if storage.file_exists:
+            QMessageBox.critical(None, "Error", _("File exists"))
+            return
 
         wizard = installwizard.InstallWizard(self.config, self.network, storage)
         wallet = wizard.run()
@@ -685,7 +683,7 @@ class ElectrumWindow(QMainWindow):
             if conf > 0:
                 try:
                     time_str = datetime.datetime.fromtimestamp( timestamp).isoformat(' ')[:-3]
-                except:
+                except Exception:
                     time_str = _("error")
 
             if conf == -1:
@@ -867,12 +865,12 @@ class ElectrumWindow(QMainWindow):
 
         try:
             amount = self.read_amount(unicode( self.amount_e.text()))
-        except:
+        except Exception:
             QMessageBox.warning(self, _('Error'), _('Invalid Amount'), _('OK'))
             return
         try:
             fee = self.read_amount(unicode( self.fee_e.text()))
-        except:
+        except Exception:
             QMessageBox.warning(self, _('Error'), _('Invalid Fee'), _('OK'))
             return
 
@@ -889,7 +887,7 @@ class ElectrumWindow(QMainWindow):
 
         try:
             tx = self.wallet.mktx_from_account( [(to_address, amount)], password, fee, self.current_account)
-        except BaseException, e:
+        except Exception as e:
             traceback.print_exc(file=sys.stdout)
             self.show_message(str(e))
             return
@@ -918,7 +916,7 @@ class ElectrumWindow(QMainWindow):
                 with open(fileName,'w') as f:
                     f.write(json.dumps(tx.as_dict(),indent=4) + '\n')
                 QMessageBox.information(self, _('Unsigned transaction created'), _("Unsigned transaction was saved to file:") + " " +fileName, _('OK'))
-            except:
+            except Exception:
                 QMessageBox.warning(self, _('Error'), _('Could not write transaction to file'), _('OK'))
 
         # add recipient to addressbook
@@ -1124,8 +1122,9 @@ class ElectrumWindow(QMainWindow):
         menu.addAction(_("Copy to clipboard"), lambda: self.app.clipboard().setText(addr))
         menu.addAction(_("QR code"), lambda: self.show_qrcode("bitcoin:" + addr, _("Address")) )
         menu.addAction(_("Edit label"), lambda: self.edit_label(True))
-        menu.addAction(_("Private key"), lambda: self.show_private_key(addr))
-        menu.addAction(_("Sign message"), lambda: self.sign_message(addr))
+        if self.wallet.seed:
+            menu.addAction(_("Private key"), lambda: self.show_private_key(addr))
+            menu.addAction(_("Sign message"), lambda: self.sign_message(addr))
         if addr in self.wallet.imported_keys:
             menu.addAction(_("Remove from wallet"), lambda: self.delete_imported_key(addr))
 
@@ -1553,7 +1552,7 @@ class ElectrumWindow(QMainWindow):
         if self.wallet.seed:
             try:
                 mnemonic = self.wallet.get_mnemonic(password)
-            except:
+            except Exception:
                 QMessageBox.warning(self, _('Error'), _('Incorrect Password'), _('OK'))
                 return
             from seed_dialog import SeedDialog
@@ -1634,7 +1633,7 @@ class ElectrumWindow(QMainWindow):
         if not address: return
         try:
             pk_list = self.wallet.get_private_key(address, password)
-        except BaseException, e:
+        except Exception as e:
             self.show_message(str(e))
             return
         QMessageBox.information(self, _('Private key'), _('Address')+ ': ' + address + '\n\n' + _('Private key') + ': ' + '\n'.join(pk_list), _('OK'))
@@ -1647,7 +1646,7 @@ class ElectrumWindow(QMainWindow):
         try:
             sig = self.wallet.sign_message(str(address.text()), message, password)
             signature.setText(sig)
-        except BaseException, e:
+        except Exception as e:
             self.show_message(str(e))
 
     def sign_message(self, address):
@@ -1775,7 +1774,7 @@ class ElectrumWindow(QMainWindow):
             txt.decode('hex')
             tx = Transaction(txt)
             return tx
-        except:
+        except Exception:
             pass
 
         try:
@@ -1788,7 +1787,7 @@ class ElectrumWindow(QMainWindow):
                 input_info = json.loads(tx_dict['input_info'])
                 tx.add_input_info(input_info)
             return tx
-        except:
+        except Exception:
             pass
         
         QMessageBox.critical(None, _("Unable to parse transaction"), _("Electrum was unable to parse your transaction"))
@@ -1839,7 +1838,7 @@ class ElectrumWindow(QMainWindow):
 
         try:
             tx = self.wallet.make_unsigned_transaction(outputs, None, None)
-        except BaseException, e:
+        except Exception as e:
             self.show_message(str(e))
             return
 
@@ -1892,7 +1891,7 @@ class ElectrumWindow(QMainWindow):
             export_error_label = _("Electrum was unable to produce a private key-export.")
             QMessageBox.critical(None, _("Unable to create csv"), export_error_label + "\n" + str(reason))
 
-        except BaseException, e:
+        except Exception as e:
           self.show_message(str(e))
           return
 
@@ -1945,7 +1944,7 @@ class ElectrumWindow(QMainWindow):
         for key in text:
             try:
                 addr = self.wallet.import_key(key, password)
-            except BaseException as e:
+            except Exception as e:
                 badkeys.append(key)
                 continue
             if not addr: 
@@ -1985,7 +1984,7 @@ class ElectrumWindow(QMainWindow):
         lang_combo.addItems(languages.values())
         try:
             index = languages.keys().index(self.config.get("language",''))
-        except:
+        except Exception:
             index = 0
         lang_combo.setCurrentIndex(index)
         grid.addWidget(lang_combo, 1, 1)
@@ -2034,7 +2033,7 @@ class ElectrumWindow(QMainWindow):
         fee = unicode(fee_e.text())
         try:
             fee = self.read_amount(fee)
-        except:
+        except Exception:
             QMessageBox.warning(self, _('Error'), _('Invalid value') +': %s'%fee, _('OK'))
             return
 
@@ -2044,7 +2043,7 @@ class ElectrumWindow(QMainWindow):
         try:
             nz = int( nz )
             if nz>8: nz=8
-        except:
+        except Exception:
             QMessageBox.warning(self, _('Error'), _('Invalid value')+':%s'%nz, _('OK'))
             return
 
@@ -2140,7 +2139,7 @@ class ElectrumWindow(QMainWindow):
                     w = None
                 cb.clicked.connect(mk_toggle(cb,p,w))
                 grid.addWidget(HelpButton(p.description()), i, 2)
-            except:
+            except Exception:
                 print_msg(_("Error: cannot display plugin"), p)
                 traceback.print_exc(file=sys.stdout)
         grid.setRowStretch(i+1,1)
