@@ -37,6 +37,7 @@ from transaction import Transaction
 from plugins import run_hook
 
 COINBASE_MATURITY = 100
+DUST_THRESHOLD = 5430
 
 # AES encryption
 EncodeAES = lambda secret, s: base64.b64encode(aes.encryptData(secret,s))
@@ -54,8 +55,8 @@ def pw_decode(s, password):
         secret = Hash(password)
         try:
             d = DecodeAES(secret, s)
-        except:
-            raise BaseException('Invalid password')
+        except Exception:
+            raise Exception('Invalid password')
         return d
     else:
         return s
@@ -116,7 +117,7 @@ class WalletStorage:
             return
         try:
             d = ast.literal_eval( data )  #parse raw data from reading wallet file
-        except:
+        except Exception:
             raise IOError("Cannot read wallet file.")
 
         self.data = d
@@ -191,7 +192,7 @@ class Wallet:
         for k,v in tx_list.items():
             try:
                 tx = Transaction(v)
-            except:
+            except Exception:
                 print_msg("Warning: Cannot deserialize transactions. skipping")
                 continue
 
@@ -255,11 +256,11 @@ class Wallet:
         seed = self.get_seed(password)
         try:
             address = address_from_private_key(sec)
-        except:
-            raise BaseException('Invalid private key')
+        except Exception:
+            raise Exception('Invalid private key')
 
         if self.is_mine(address):
-            raise BaseException('Address already in wallet')
+            raise Exception('Address already in wallet')
         
         # store the originally requested keypair into the imported keys table
         self.imported_keys[address] = pw_encode(sec, password )
@@ -295,7 +296,7 @@ class Wallet:
         import mnemonic
         
         if self.seed: 
-            raise BaseException("a seed exists")
+            raise Exception("a seed exists")
 
         if not seed:
             self.seed = random_seed(128)
@@ -309,11 +310,11 @@ class Wallet:
 
         # find out what kind of wallet we are
         try:
-            seed.decode('hex')
+            seed.strip().decode('hex')
             self.seed_version = 4
             self.seed = str(seed)
             return
-        except:
+        except Exception:
             pass
 
         words = seed.split()
@@ -323,7 +324,7 @@ class Wallet:
         #try:
         #    mnemonic.mn_decode(words)
         #    uses_electrum_words = True
-        #except:
+        #except Exception:
         #    uses_electrum_words = False
         #
         #if uses_electrum_words and len(words) != 13:
@@ -338,6 +339,8 @@ class Wallet:
     def save_seed(self):
         self.storage.put('seed', self.seed, True)
         self.storage.put('seed_version', self.seed_version, True)
+        self.create_accounts()
+
 
     def create_watching_only_wallet(self, params):
         K0, c0 = params
@@ -346,6 +349,7 @@ class Wallet:
 
         if not c0:
             self.seed_version = 4
+            self.storage.put('seed_version', self.seed_version, True)
             self.create_old_account(K0)
             return
 
@@ -354,6 +358,7 @@ class Wallet:
             "m/0'/": (c0, K0, cK0),
             }
         self.storage.put('master_public_keys', self.master_public_keys, True)
+        self.storage.put('seed_version', self.seed_version, True)
         self.create_account('1','Main account')
 
 
@@ -435,7 +440,7 @@ class Wallet:
         elif account_type == '2of3':
             return "m/3'/%d & m/4'/%d & m/5'/%d"%(i,i,i)
         else:
-            raise BaseException('unknown account type')
+            raise Exception('unknown account type')
 
 
     def num_accounts(self, account_type):
@@ -605,8 +610,8 @@ class Wallet:
         try:
             K, Kc = get_pubkeys_from_secret(master_k.decode('hex'))
             assert K.encode('hex') == master_K
-        except:
-            raise BaseException("Invalid password")
+        except Exception:
+            raise Exception("Invalid password")
         return master_k
 
 
@@ -625,7 +630,7 @@ class Wallet:
             if v == address:
                 return k, (0,0)
 
-        raise BaseException("Address not found", address)
+        raise Exception("Address not found", address)
 
 
     def get_roots(self, account):
@@ -677,9 +682,9 @@ class Wallet:
         s = pw_decode(self.seed, password)
         if self.seed_version == 4:
             seed = s
+            self.accounts[0].check_seed(seed)
         else:
             seed = mnemonic_hash(s)
-        #todo:  #self.sequences[0].check_seed(seed)
         return seed
         
 
@@ -694,13 +699,15 @@ class Wallet:
         
 
     def get_private_key(self, address, password):
+        # first check the provided password
+        seed = self.get_seed(password)
+        
         out = []
         if address in self.imported_keys.keys():
             out.append( pw_decode( self.imported_keys[address], password ) )
         else:
             account, sequence = self.get_address_index(address)
             if account == 0:
-                seed = self.get_seed(password)
                 pk = self.accounts[account].get_private_key(seed, sequence)
                 out.append(pk)
                 return out
@@ -1107,9 +1114,10 @@ class Wallet:
             if h == ['*']: continue
             for tx_hash, tx_height in h:
                 tx = self.transactions.get(tx_hash)
-                if tx is None: raise BaseException("Wallet not synchronized")
+                if tx is None: raise Exception("Wallet not synchronized")
                 is_coinbase = tx.inputs[0].get('prevout_hash') == '0'*64
-                for output in tx.d.get('outputs'):
+                for o in tx.d.get('outputs'):
+                    output = o.copy()
                     if output.get('address') != addr: continue
                     key = tx_hash + ":%d" % output.get('prevout_n')
                     if key in self.spent_outputs: continue
@@ -1185,7 +1193,7 @@ class Wallet:
     def add_tx_change( self, inputs, outputs, amount, fee, total, change_addr=None):
         "add change to a transaction"
         change_amount = total - ( amount + fee )
-        if change_amount != 0:
+        if change_amount > DUST_THRESHOLD:
             if not change_addr:
 
                 # send change to one of the accounts involved in the tx
@@ -1242,7 +1250,7 @@ class Wallet:
     def receive_history_callback(self, addr, hist):
 
         if not self.check_new_history(addr, hist):
-            raise BaseException("error: received history for %s is not consistent with known transactions"%addr)
+            raise Exception("error: received history for %s is not consistent with known transactions"%addr)
             
         with self.lock:
             self.history[addr] = hist
@@ -1405,8 +1413,7 @@ class Wallet:
 
     def update_password(self, old_password, new_password):
         if new_password == '': new_password = None
-        # this will throw an exception if unicode cannot be converted
-        decoded = pw_decode(self.seed, old_password)
+        decoded = self.get_seed(old_password)
         self.seed = pw_encode( decoded, new_password)
         self.storage.put('seed', self.seed, True)
         self.use_encryption = (new_password != None)
@@ -1603,10 +1610,6 @@ class Wallet:
         # wait until we are connected, because the user might have selected another server
         if self.network:
             wait_for_network()
-
-        self.create_accounts()
-
-        if self.network:
             wait_for_wallet()
         else:
             self.synchronize()
@@ -1751,12 +1754,12 @@ class WalletSynchronizer(threading.Thread):
                             hist.append( (tx_hash, item['height']) )
 
                     if len(hist) != len(result):
-                        raise BaseException("error: server sent history with non-unique txid", result)
+                        raise Exception("error: server sent history with non-unique txid", result)
 
                     # check that the status corresponds to what was announced
                     rs = requested_histories.pop(addr)
                     if self.wallet.get_status(hist) != rs:
-                        raise BaseException("error: status mismatch: %s"%addr)
+                        raise Exception("error: status mismatch: %s"%addr)
                 
                     # store received history
                     self.wallet.receive_history_callback(addr, hist)
